#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from typing import List
from astra_csp.cprocsp_process import CprocspProcess
from astra_csp.utils import Utils


class Certificate:
    def __init__(self, fingerprint: str, subject: str):
        self.__fingerprint = fingerprint
        self.__subject = subject

    def __repr__(self) -> str:
        return self.fingerprint + ' ' + self.subject

    @property
    def fingerprint(self) -> str:
        return self.__fingerprint

    @property
    def subject(self) -> str:
        return self.__subject


class CertificateProcess(CprocspProcess):
    def __init__(self) -> None:
        super().__init__()
        self.__setup()

    def __setup(self) -> None:
        self.setProgram('/opt/cprocsp/bin/amd64/certmgr')
        self.setArguments(['-list'])

    def get_certificates(self) -> List[Certificate]:  # TODO: old code
        sertificates = []  # type: List[Certificate]
        for line in Utils.to_utf8(self.standard_output_buffer).split('\n'):
            parm = line.partition(' : ')
            if len(parm) < 1:
                continue
            if parm[0].startswith('Subject') or parm[0].startswith('Субъект'):
                subject = parm[2].strip()
            if parm[0].startswith('SHA1') or parm[0].startswith('Хэш SHA1'):
                if len(parm) < 3:
                    continue
                sertificates.append(Certificate(fingerprint=parm[2].strip(), subject=subject))
        return sertificates
