#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from typing import Optional
from re import match, sub
from astra_csp.process import Process
from astra_csp.utils import Utils


class CprocspProcess(Process):
    def __init__(self) -> None:
        super().__init__()

    def output_error_code(self) -> Optional[str]:
        for line in Utils.to_utf8(self.standard_output_buffer).split('\n'):
            result = match(r'^\[ErrorCode: (?P<code>.+)\]$', line)
            if result:
                return result.group('code')

        return None

    def failed_output_error_code_occurred(self) -> bool:
        return self.output_error_code() != '0x00000000'

    def timestamp_error_occurred(self) -> bool:
        return self.output_error_code() == '0xc2100100'

    def output(self) -> str:
        text = Utils.to_utf8(self.standard_output_buffer)
        text = sub('\\s\\d+%', '', text.replace('\n', '<br>').replace('', ''))

        if self.timestamp_error_occurred():
            text += '<br>' + self.tr('Error: Timestamp not received')

        return text
