#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5.QtWidgets import QWidget
from PyQt5.QtCore import QByteArray, Qt
from PyQt5.QtGui import QKeyEvent
from astra_csp.interactive_process_dialog import InteractiveProcessDialog
from astra_csp.cprocsp_process import CprocspProcess


class CprocspProcessDialog(InteractiveProcessDialog):
    def __init__(self, process: CprocspProcess, parent: QWidget = None) -> None:
        super().__init__(process=process, parent=parent)
        self.__setup()

    # noinspection PyPep8Naming
    def keyPressEvent(self, event: QKeyEvent) -> None:
        if event.key() == Qt.Key_Return:
            self._process.write(b'f\n')
        elif len(event.text()) > 0:
            self._process.write(QByteArray(len(event.text()), event.text()))
            super().keyPressEvent(event)

    def __setup(self) -> None:
        self.waitLabel.setVisible(False)
        self.textEdit.setVisible(True)
        self._process.readyReadStandardOutput.connect(self.__on_process_ready_read_standard_output)

    def __on_process_ready_read_standard_output(self) -> None:
        self.textEdit.setText(self._process.output())
