#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5 import uic
from PyQt5.QtWidgets import QDialog, QWidget, QLineEdit, QLabel, QDialogButtonBox
from typing import Optional
from astra_csp.process import Process
from astra_csp.utils import Utils

dialog_ui = Utils.file_path('ui', 'interactiveprocess.ui')
UiFormClass, UiFormBase = uic.loadUiType(dialog_ui)  # type: QDialog, QDialog


class InteractiveProcessDialog(UiFormClass, UiFormBase):
    def __init__(self, process: Process, parent: QWidget = None) -> None:
        super().__init__(parent=parent)
        self._process = process
        self.waitLabel = None  # type: Optional[QLabel]
        self.textEdit = None  # type: Optional[QLineEdit]
        self.buttonBox = None  # type: Optional[QDialogButtonBox]
        self.setupUi(self)
        self.__setup()

    def __setup(self) -> None:
        self.setModal(True)
        self.setWindowTitle(self._process.command)
        self._process.finished.connect(self.__on_process_finished)
        self.rejected.connect(self.__on_rejected)

        self.waitLabel.setVisible(True)
        self.textEdit.setVisible(False)
        self.adjustSize()

    def __on_process_finished(self) -> None:
        self.close()

    def __on_rejected(self) -> None:
        self._process.kill()
