#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import sys

from PyQt5.QtCore import QTranslator, QLocale, QLibraryInfo, QCommandLineParser
from PyQt5.QtWidgets import QApplication

from astra_csp.mainwindow import MainWindow
from astra_csp.utils import Utils

translate = QApplication.translate


def main() -> None:
    app = QApplication(sys.argv)
    system_translator = QTranslator(app)
    app_translator = QTranslator(app)
    locale = Utils.get_lang()
    system_translator.load('qt_' + locale, QLibraryInfo.location(QLibraryInfo.TranslationsPath))
    app_translator.load(QLocale(locale), '', '', Utils.file_path('translations'), '.qm')
    QApplication.instance().installTranslator(system_translator)
    QApplication.instance().installTranslator(app_translator)
    parser = QCommandLineParser()
    parser.addPositionalArgument('file', translate('text', 'The file to verify or sign.'))
    parser.addPositionalArgument('signature', translate('text', 'The signature to verify.'),
                                 translate('text', '[signature]'))
    parser.addHelpOption()
    parser.process(app)
    window = MainWindow()
    window.show()
    window.initialize(parser.positionalArguments())
    sys.exit(app.exec_())


if __name__ == '__main__':
    main()
