#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5.QtCore import QProcess, QTimer, QByteArray


class Process(QProcess):
    def __init__(self) -> None:
        super().__init__()
        self.__timer = QTimer()
        self.__standard_output_buffer = QByteArray()
        self.__setup()

    @property
    def kill_time(self) -> int:
        return self.__timer.interval()

    @kill_time.setter
    def kill_time(self, ms: int) -> None:
        self.__timer.setInterval(ms)

    @property
    def command(self) -> str:
        return ' '.join([self.program()] + self.arguments())

    @property
    def standard_output_buffer(self) -> QByteArray:
        return self.__standard_output_buffer

    def __setup(self) -> None:
        self.__timer.setSingleShot(True)
        self.__timer.timeout.connect(self.__timer_on_timeout)
        self.started.connect(self.__on_started)
        self.readyReadStandardOutput.connect(self.__on_ready_read_standard_output)

    def __timer_on_timeout(self) -> None:
        self.kill()

    def __on_started(self) -> None:
        self.__standard_output_buffer.clear()
        if self.kill_time > 0:
            self.__timer.start()

    def __on_ready_read_standard_output(self) -> None:
        self.__standard_output_buffer += self.readAllStandardOutput()
