# -*- coding: utf-8 -*-

import os
from re import match
from typing import Optional, List

from PyQt5.QtCore import QMimeDatabase, QUrl, QDir, QByteArray, QProcess
from PyQt5.QtGui import QDesktopServices


class Utils:
    astra_edition_regex = r'^(?P<edition>\w+)\s+(?P<release>.*?)\s+\(?(?P<name>\w+)\)?$'

    @classmethod
    def file_path(cls, *paths) -> str:
        package_directory = os.path.dirname(os.path.abspath(__file__))
        return os.path.join(package_directory, *paths)

    @staticmethod
    def get_lang() -> Optional[str]:
        return os.environ.get('LANG')

    @staticmethod
    def file_is_exists(path: str) -> bool:
        return os.path.isfile(path)

    @staticmethod
    def readfile(file_path: str) -> List[str]:
        with open(file_path, 'r') as file:
            lines = file.readlines()
        return lines

    @staticmethod
    def match_astra_version(group: str) -> str:
        content = Utils.readfile('/etc/astra_version')[0]
        result = match(Utils.astra_edition_regex, content)
        return result.group(group) if match else 'unknown'

    @staticmethod
    def get_edition_from_environment() -> str:
        return Utils.match_astra_version('edition')

    @staticmethod
    def is_ce_edition() -> bool:
        return Utils.get_edition_from_environment() == 'CE'

    @staticmethod
    def get_mac_level() -> int:
        if Utils.is_ce_edition():
            return 0

        process = QProcess()
        process.start('pdp-id -l')
        process.waitForFinished()
        if process.exitStatus() != QProcess.NormalExit or process.exitCode() != 0:
            raise Exception(process.errorString())
        return int(Utils.to_utf8(process.readAll()))

    @staticmethod
    def file_mimetypes(path: str) -> str:
        return QMimeDatabase().mimeTypeForFile(path).name()

    @staticmethod
    def open_file(file_path: str) -> None:
        QDesktopServices.openUrl(QUrl.fromLocalFile(file_path))

    @staticmethod
    def create_directory(path: str) -> bool:
        return QDir(path).mkpath('.')

    @staticmethod
    def delete_directory(path: str) -> bool:
        return QDir(path).removeRecursively()

    @staticmethod
    def to_utf8(array: QByteArray) -> str:
        return str(array.data(), 'utf-8')
